@@ -45,7 +45,7 @@ namespace {
 static size_t NUM_COLS;
 static size_t K;
 static size_t NUM_ROWS;
-short OMP_MAX_THREADS;
+short OMP_MAX_THREADS = 1;
 static size_t g_num_changed = 0;
 static struct timeval start, end;
 static kpmbase::init_type_t g_init_type;
@@ -393,16 +393,18 @@ kpmbase::kmeans_t compute_min_kmeans(const double* matrix, double* clusters_ptr,
     NUM_COLS = num_cols;
     K = k;
     NUM_ROWS = num_rows;
+#ifdef _OPENMP
     if (!max_threads)
         max_threads = 1;
-
-#ifdef _OPENMP
-    OMP_MAX_THREADS = std::min(max_threads, kpmbase::get_num_omp_threads());
-    omp_set_num_threads(OMP_MAX_THREADS);
 #else
-    OMP_MAX_THREADS = 1;
+    max_threads = 1;
 #endif
 
+    OMP_MAX_THREADS = std::min(max_threads, kpmbase::get_num_omp_threads());
+
+#ifdef _OPENMP
+    omp_set_num_threads(OMP_MAX_THREADS);
+#endif
 #ifndef BIND
     printf("Running on %i threads!\n", OMP_MAX_THREADS);
 #endif
